/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 15.09.2008
 * Modified: $Date $
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.authentication;

import javax.security.auth.Subject;

/**
 * Class ExternalProvidedSubjectCredential is used to transport an external subject through some interface boarders,
 * where only a credential interface is provided.
 * <p/>
 * One case to imagine is in soap service environments where an external module verifies the real credentials
 * and creates an subject by self. Than with this class the created subject can be transported and be used within the
 * AuthenticationService to transform it by login modules in a new subject.
 *
 * @author Marko Reiprecht
 *         Created on 15.09.2008
 * @version $Revision: $
 */
public class ExternalProvidedSubjectCredential implements Credential {

    /**
     * Uuse this key to communicate in attriubte scopes about a external subject.
     */
    public static final String KEY_EXTERNAL_SUBJECT = "external.provided.subject";

    private Subject m_subject;

    /**
     * Constructor creates a new instance.
     *
     * @param subject the subject.
     */
    public ExternalProvidedSubjectCredential(final Subject subject) {
        if (subject == null) {
            throw new IllegalArgumentException("subject must not null");
        }
        m_subject = subject;
    }

    /**
     * Method gets the subject.
     *
     * @return Subject.
     */
    public Subject getSubject() {
        return m_subject;
    }
}
