/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 18.07.2008
 * Modified: $Date $
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.authentication.callbacks;

import javax.security.auth.callback.Callback;
import org.n52.security.authentication.Credential;

/**
 * Class CredentialCallback describes the requirement for a special credential class.
 * The callback is used by login modules to request special credential information.
 *
 * @author Marko Reiprecht
 *         Created on 18.07.2008
 * @version $Revision: $
 */
public class CredentialCallback implements Callback {

    private Class m_requiredCredentialClass;
    private Credential m_credential;

    /**
     * Constructor creates a new instance, this callback asks for a credential with the given class.
     *
     * @param requiredCredentialClass the requiredCredentialClass.
     */
    public CredentialCallback(final Class requiredCredentialClass) {
        m_requiredCredentialClass = requiredCredentialClass;
    }

    /**
     * Constructor creates a new instance, this callback asks for a credential of the given default value.
     *
     * @param credential the credential.
     */
    public CredentialCallback(final Credential credential) {
        m_requiredCredentialClass = credential.getClass();
        m_credential = credential;
    }

    /**
     * Method gets the requiredCredentialClass.
     *
     * @return Class.
     */
    public Class getRequiredCredentialClass() {
        return m_requiredCredentialClass;
    }

    /**
     * Method sets the requiredCredentialClass.
     *
     * @param requiredCredentialClass the requiredCredentialClass.
     */
    public void setRequiredCredentialClass(final Class requiredCredentialClass) {
        m_requiredCredentialClass = requiredCredentialClass;
    }

    /**
     * Method gets the credential.
     *
     * @return Credential.
     */
    public Credential getCredential() {
        return m_credential;
    }

    /**
     * Method sets the credential.
     *
     * @param credential the credential.
     */
    public void setCredential(final Credential credential) {
        m_credential = credential;
    }
}
