/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.authentication.loginmodule;

import org.n52.security.authentication.Credential;

/**
 * Marker interface for credential cache entries managed by {@link CredentialCache}.
 * 
 * Implementations must provide a custom
 * 
 * <ul>
 * <li> {@link #equals(Object)}
 * <li> {@link #hashCode()}
 * </ul>
 * 
 * method.
 * 
 * @author drewnak
 * 
 */
public abstract class CredentialCacheEntry {

    private long m_entryTime;

    /**
     * @return the entryTime
     */
    public long getEntryTime() {
        return m_entryTime;
    }

    /**
     * @param entryTime
     *            the entryTime to set
     */
    void setEntryTime(final long entryTime) {
        m_entryTime = entryTime;
    }

    abstract Credential getCredential();

    abstract String getId();

    public boolean isEntryFor(final String cacheId) {
        if (cacheId == null || getId() == null) {
            return false;
        }
        return getId().equals(cacheId);
    }

    /**
     * @return <code>true</code> if the credential itself is only valid for a limited amount of time, <code>false</code>
     *         otherwise.
     */
    abstract boolean internallyExpires();

    /**
     * @return <code>true</code> if the credential itself is expired, <code>false</code> otherwise. Should always return
     *         <code>false</code> if {@link #internallyExpires()} returns <code>false</code>.
     */
    abstract boolean isInternallyExpired();

    abstract Object getCredentialCopy();
}
