/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.util;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import org.apache.commons.codec.binary.Base64;

/**
 * This class provides some utilities to work with strings in the 52n security services suite. 
 */
public final class StringUtils {

    /**
     *
     */
    private StringUtils() {
        super();
        // TODO Auto-generated constructor stub
    }

    /**
     * Decodes a Base64 encoded String. Interprets bytes as UTF-8 encoded by default.
     * 
     * @param pEncodedString
     * @return
     */
    public static String decodeBase64(String pEncodedString) {
        try {
            byte[] encodedBytes = pEncodedString.getBytes("UTF-8");
            // this is only a low protection, an don't say that the given bytes really base64.
            if (Base64.isArrayByteBase64(encodedBytes)) {
                return new String(Base64.decodeBase64(encodedBytes), "UTF-8");
            }
            // is not base 64 encoded
            return pEncodedString;
        } catch (UnsupportedEncodingException e) {
            throw new RuntimeException("Could not encode String from bytes properly.", e);
        }
    }

    /**
     * Encoded a String into another Base64 encoded String. Interprets String as UTF-8 encoded by default.
     * 
     * @param pString
     * @return
     */
    public static String encodeBase64(String pString) {
        try {
            return new String(Base64.encodeBase64(pString.getBytes("UTF-8")), "UTF-8");
        } catch (UnsupportedEncodingException e) {
            throw new RuntimeException("Could not decode String into bytes properly.", e);
        }
    }

    public static String getStreamAsString(InputStream is) throws Exception {
        BufferedReader br = new BufferedReader(new InputStreamReader(is));
        StringBuffer response = new StringBuffer();
        String line = null;
        while ((line = br.readLine()) != null) {
            response.append(line);
        }

        return response.toString();
    }

}
