/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 24.03.2008
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.common.xml;

import javax.xml.parsers.DocumentBuilder;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.w3c.dom.Document;
import org.xml.sax.EntityResolver;
import org.xml.sax.ErrorHandler;
import org.xml.sax.InputSource;

/**
 * Class NonPooledDOMParser is a DOMParser which creates a new DocumentBuilder for his own use.
 *
 * @author Marko Reiprecht
 *         Created on 24.03.2008
 * @version $Revision: $
 */
class NonPoolingDOMParser extends DOMParser {

    // ------------------------------ FIELDS ------------------------------

    /**
     * The Logger.
     */
    private static final Log LOG = LogFactory.getLog(NonPoolingDOMParser.class);

    private DocumentBuilder m_documentBuilder;

    // --------------------------- CONSTRUCTORS ---------------------------

    /**
     * Constructor creates a new instance.
     * <p/>
     * It's protected because you shall use the {@link DOMParser#createNonPoolingParser()} methods.
     *
     * @param options the options.
     */
    protected NonPoolingDOMParser(final DOMParserOptions options) {
        m_documentBuilder = createDocumentBuilder(options);
    }

    // -------------------------- OTHER METHODS --------------------------

    /**
     * @see DOMParser#parse(InputSource, ErrorHandler, EntityResolver)
     */
    public Document parse(final InputSource inputSource, final ErrorHandler errorhandler,
                          final EntityResolver entityResolver) throws DOMParserException {
        try {
            m_documentBuilder.setEntityResolver(entityResolver);
            m_documentBuilder.setErrorHandler(errorhandler);
            return m_documentBuilder.parse(inputSource);
        } catch (Exception ex) {
            throw new DOMParserException("unexpected exception during parsing", ex);
        }
    }
}