/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.decision;

import java.io.Serializable;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;


/**
 * This class encapsulates PDPRequests.
 * Each PDPRequestCollection should be processed as one request to PEP.
 *
 * @author Bastian Schaeffer
 * @author Marko Reiprecht
 * @version $Revision: 1748 $
 */
public class PDPRequestCollection implements Serializable {

    // ------------------------------ FIELDS ------------------------------

    private static final long serialVersionUID = 7179636614047605915L;

    /**
     * List of {@link PDPRequest} instances.
     */
    protected List m_requests = new LinkedList();

    // --------------------------- CONSTRUCTORS ---------------------------

    /**
     * Constructor creates a new instance.
     */
    public PDPRequestCollection() {}

    /**
     * Constructor creates a new instance.
     *
     * @param pdpRequest the pdpRequest.
     */
    public PDPRequestCollection(final PDPRequest pdpRequest) {
        this.add(pdpRequest);
    }

    /**
     * Method add.
     *
     * @param request the request.
     * @return this.
     */
    public PDPRequestCollection add(final PDPRequest request) {
        m_requests.add(request);
        return this;
    }

    // ------------------------ CANONICAL METHODS ------------------------

    /**
     * Method equals.
     *
     * @param o the o.
     * @return boolean.
     */
    public boolean equals(final Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }

        final PDPRequestCollection that = (PDPRequestCollection) o;

        if (!m_requests.equals(that.m_requests)) {
            return false;
        }

        return true;
    }

    /**
     * Method hashCode.
     *
     * @return int.
     */
    public int hashCode() {
        return m_requests.hashCode();
    }

    /**
     * Method toString.
     *
     * @return String.
     */
    public String toString() {
        final StringBuffer sb = new StringBuffer();
        sb.append("org.n52.security.decision.PDPRequestCollection");
        sb.append("{m_requests=").append(m_requests);
        sb.append('}');
        return sb.toString();
    }

    // -------------------------- OTHER METHODS --------------------------

    /**
     * Method iterator.
     *
     * @return Iterator.
     */
    public Iterator iterator() {
        return m_requests.iterator();
    }

    /**
     * Method remove.
     *
     * @param request the request.
     * @return this.
     */
    public PDPRequestCollection remove(final PDPRequest request) {
        m_requests.remove(request);
        return this;
    }

    /**
     * Method size.
     *
     * @return int.
     */
    public int size() {
        return m_requests.size();
    }

    /**
     * Method isEmpty.
     *
     * @return boolean.
     */
    public boolean isEmpty() {
        return m_requests.isEmpty();
    }
}